@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -13,4 +13,4 @@ foreach ($interfaces as $int){
 	$result = interface_adjust_rrd($int[id],$int[bandwidthin],$int[bandwidthout]);
     echo "Result $result\n";
 }
-?>
\ No newline at end of file
+?>
