@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -55,7 +55,7 @@
 	return $output;
     }
 
-    function MIBParser_Process($data,$idents,$result,$part) {
+    function MIBParser_Process(&$data,&$idents,&$result,$part) {
 	
 	while (list($key,$line) = each ($data)) {
 
@@ -73,7 +73,7 @@
 
 		    unset ($part);
 		    $part[]=$line;
-		    MIBParser_Process(&$data,&$idents,&$result[$section][$name],&$part);
+		    MIBParser_Process($data,$idents,$result[$section][$name],$part);
 		    $aux = join(" ",$part);
 		}
 		
@@ -134,7 +134,7 @@
 	//var_dump($mib_data); die();
 	
 	$result = Array();
-	MIBParser_Process(&$mib_data,&$idents,&$result,Array());
+	MIBParser_Process($mib_data,$idents,$result,Array());
 	$mib_name = key($result[module]);
 	return Array(name=>$mib_name,mib=>$result[module][$mib_name]);
     }
@@ -206,4 +206,4 @@
     
     }
     echo "</table>\n";
-?>
\ No newline at end of file
+?>
