@@ -1,4 +1,4 @@
-<? 
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -53,4 +53,4 @@
 
     }
 
-?>
\ No newline at end of file
+?>
