@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -9,15 +9,16 @@
     $readsize=15000;
     
     $process_data_func = "process_data2";
-    $read_file_func = "read_file2";
+    
 
     $cant_lines = 0;
     
-    function process_line($fps,$filename,$ds_name,$line,$cant_ds,$save_ds,$new_lines,$last_update,$ds) {
+    function process_line(&$fps,$filename,$ds_name,$line,&$cant_ds,&$save_ds,&$new_lines,&$last_update,&$ds) {
 	    //if ($GLOBALS[cant_lines] >= 10000) return 1;
-	    $GLOBALS[cant_lines]++;
-	    //echo "$line\n";
-	    //var_dump($line);
+        global $cant_lines;
+        global $process_data_func;
+
+	    $cant_lines++;
 	    $pos = strpos($line,"<v>");
 	    $pos1 = strpos($line,"<lastupdate>");
 	    
@@ -40,11 +41,11 @@
 	    //$cant_part = 10;
 
 	    if (($cant_new_lines > 1) && ($cant_new_lines%$cant_part==0))  
-		$GLOBALS[process_data_func](&$fps,$filename,&$new_lines,$cant_part,&$cant_ds);    
+		$process_data_func($fps,$filename,$new_lines,$cant_part,$cant_ds);    
 	    
     }    
 
-    function read_file2 ($fps,$filename,$ds_name,$interface_id) {
+    function read_file2 (&$fps,&$filename,$ds_name,$interface_id) {
 	
 	$fp = fopen($filename,"r");
 	$filename = $GLOBALS[rrd_real_path]."/interface-".$interface_id;
@@ -77,7 +78,7 @@
 	
 		    //if ($new_line=="<rra>") break;
 		    if ($new_line=="</rra>") {$b = 1; break;}
-		    if ($new_line) $b = process_line(&$fps,$filename,$ds_name,$new_line,&$cant_ds,&$save_ds,&$new_lines,&$last_update,&$ds);
+		    if ($new_line) $b = process_line($fps,$filename,$ds_name,$new_line,$cant_ds,$save_ds,$new_lines,$last_update,$ds);
 
 		    $aux = substr($aux,$pos1+1,strlen($aux));
 		}
@@ -92,7 +93,7 @@
 	return count($ds);
     }
 
-    function process_data2 ($fps,$filename,$new_lines,$cant_part,$cant_ds) { 
+    function process_data2 (&$fps,$filename,&$new_lines,$cant_part,&$cant_ds) { 
 	$data = array_splice($new_lines,0,$cant_part);
 	for ($i = 0; $i < $cant_part; $i++) {
 	    $pos2 = 0;    
@@ -148,12 +149,12 @@
 
     
     function start ($filename,$interface_id) {
-	global $fps,$read_file_func,$cant_lines;
+	global $fps,$cant_lines;
 	
 	$dsname="ds";
 	$start = gettimeofday();
     
-	$cant_ds = $read_file_func(&$fps,&$filename,$dsname,$interface_id);
+	$cant_ds = $read_file2($fps,$filename,$dsname,$interface_id);
 	$end = gettimeofday();
     
 	for ($i = 0; $i < $cant_ds; $i++)
