@@ -1,13 +1,12 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
     //Do Nothing
 
-    function action_none ($data) {
-    
-	return 0;
-    }
-
-?>
\ No newline at end of file
+function action_none ($data)
+{
+  return 0;
+}
+?>
