@@ -94,7 +94,7 @@
 	return false;
     }
 
-    function nmap_pipe ($target, $data) {
+    function nmap_pipe ($target, &$data) {
         global $Config;
     
 	if (!is_array($data[$target])) {
@@ -128,7 +128,7 @@
 	
 	nad_network_status ($net_data["id"], 2); //Running
 
-	while ($line = nmap_pipe($network, &$nmap_data)) 
+	while ($line = nmap_pipe($network, $nmap_data)) 
 	    if (preg_match ("/Host\: (.*) \((.*)\).*Status\: (.*)/", $line ,$parts)) {
 
 		if (!$output) launcher_heartbeat(); 
