@@ -1,11 +1,11 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
-function backend_no_backend($options,$result){
-    return 0;
+function backend_no_backend($options,$result)
+{
+  return 0;
 }
-
 ?>
