@@ -11,6 +11,7 @@ define ('ENGINE_HEARTBEAT', 30);
 define ('ENGINE_MAX_POLL_TIME', 180);
 define ('ENGINE_DIE_TIME', 5);
 define ('ENGINE_MAX_CHILDREN', 5);
+define ('ENGINE_SELECT_USEC', 2000); //PHP RECOMMENDATION is 200,000
 
 require_once('../conf/config.php');
 $Config = new JffnmsConfig();
@@ -61,12 +62,12 @@ class JffnmsEngineParent
     {
         $new_wait = count($this->waiting_items);
         if ($this->waiting_count != $new_wait) {
-            logger("Waiting count adjusted to $new_wait (was ".$this->waiting_count.")\n");
+            logger("PAR: Waiting count adjusted to $new_wait (was ".$this->waiting_count.")\n");
             $this->waiting_count = $new_wait;
         }
         $new_poll = count($this->polling_items);
         if ($this->polling_count != $new_poll) {
-            logger("polling count adjusted to $new_poll (was ".$this->polling_count.")\n");
+            logger("PAR: Polling count adjusted to $new_poll (was ".$this->polling_count.")\n");
             $this->polling_count = $new_poll;
         }
     }
@@ -79,7 +80,7 @@ class JffnmsEngineParent
             return;
         }
         if (!array_key_exists($item_id, $this->polling_items)) {
-            logger("item_set_done(): Item $item_id does not exist in poller items.\n");
+            logger("PAR: ** ERROR ** item_set_done(): Item $item_id does not exist in poller items.\n");
             $this->items_recount();
             return;
         }
@@ -94,13 +95,17 @@ class JffnmsEngineParent
             return;
         }
         if (!array_key_exists($item_id, $this->polling_items)) {
-            logger("item_set_waiting(): Item $item_id does not exist in poller items.\n");
+            logger("PAR: ** ERROR ** item_set_waiting(): Item $item_id does not exist in poller items.\n");
             $this->items_recount();
             return;
         }
-        $this->waiting_items[$item_id] = $this->polling_items[$item_id];
+        if ($this->polling_items[$item_id]['tries'] > ENGINE_MAX_TRIES) {
+            logger("PAR: Cannot process item $item_id after ".ENGINE_MAX_TRIES." attempts.\n");
+        } else {
+            $this->waiting_items[$item_id] = $this->polling_items[$item_id];
+            $this->waiting_count++;
+        }
         unset($this->polling_items[$item_id]);
-        $this->waiting_count++;
         $this->polling_count--;
     } // item_set_waiting
 
@@ -111,7 +116,7 @@ class JffnmsEngineParent
             return;
         }
         if (!array_key_exists($item_id, $this->waiting_items)) {
-            logger("item_set_polling(): Item $item_id does not exist in waiting items.\n");
+            logger("PAR: ** ERROR ** item_set_polling(): Item $item_id does not exist in waiting items.\n");
             $this->items_recount();
             return;
         }
@@ -163,13 +168,22 @@ class JffnmsEngineParent
             $new_child = $this->start_child();
             if ($new_child === FALSE)
                 return $children_started;
-            $this->child_procs[] = $new_child;
+            $this->child_procs[$this->get_child_id()] = $new_child;
             $children_count++;
             $children_started++;
         }
         return $children_started;
     } // children_start()
 
+    public function get_child_id()
+    {
+        $id=0;
+        while(TRUE) {
+            if (!array_key_exists($id, $this->child_procs))
+                return $id;
+            $id++;
+        }
+    }
     public function stop_all_children($reason)
     {
         foreach ($this->child_procs as $child_id => $child)
@@ -179,10 +193,10 @@ class JffnmsEngineParent
     public function stop_child($child_id, $reason)
     {
         if (!array_key_exists($child_id, $this->child_procs)) {
-            logger("** FATAL ** Child ID $child_id stopped but doesn't exist.\n");
+            logger("PAR: ** FATAL ** Child ID $child_id stopped but doesn't exist.\n");
             die();
         }
-        logger("Child #$child_id (PID:".$this->child_procs[$child_id]['pid'].") stopped: $reason.\n");
+        logger("CH$child_id (".$this->child_procs[$child_id]['pid']."): stopped: $reason.\n");
         $this->item_set_waiting($this->child_procs[$child_id]['item_id']);
         $this->child_procs[$child_id]['item_id']=FALSE;
         $this->child_procs[$child_id]['state']='DEAD';
@@ -199,7 +213,7 @@ class JffnmsEngineParent
             // Check that the child process actually exists
             $child_stat = proc_get_status($child['resource']);
             if ($child_stat === FALSE ) {
-                logger("Child $child_id has no status - removing.\n");
+                logger("CH:$child_id no status - removing.\n");
                 $this->item_set_waiting($child['item_id']);
                 unset($this->child_procs[$child_id]);
                 $child_count--;
@@ -207,7 +221,7 @@ class JffnmsEngineParent
             }
             if ($child_stat['running'] === FALSE) {
                 if ($child['state'] != 'DEAD')
-                    logger("Child $child_id is no longer running - removing.\n");
+                    logger("CH:$child_id No longer running - removing.\n");
                 $this->item_set_waiting($child['item_id']);
                 proc_close($child['resource']);
                 unset($this->child_procs[$child_id]);
@@ -238,7 +252,7 @@ class JffnmsEngineParent
                 break;
             case 'DEAD':
                 if ($child['killtime'] + ENGINE_DIE_TIME < $now) {
-                    logger("Child #$child_id (PID:$child[pid]) took too long to die.\n");
+                    logger("CH:$child_id ($child[pid]): took too long to die.\n");
                     proc_close($child['resource']);
                     unset($this->child_procs[$child_id]);
                     $child_count--;
@@ -249,7 +263,7 @@ class JffnmsEngineParent
         } // foreach children
     }
 
-    public function read_children()
+    public function read_children($callback_function)
     {
         $read_fds = array();
         $write_fds = NULL;
@@ -262,59 +276,83 @@ class JffnmsEngineParent
         if (sizeof($read_fds) == 0)
             return FALSE;
 
+        $child_had_data = FALSE;
         if ( ($nr = stream_select($read_fds, $write_fds, $except_fds, 0)) !== FALSE) {
             if ($nr == 0)
                 return FALSE;
             foreach($this->child_procs AS $child_id => &$child_proc) {
                 if ( in_array($child_proc['output'], $read_fds)) {
-                    if ( ($raw_data = fgets($child_proc['output'])) !== FALSE) {
-                        $child_proc['lastseen'] = $now;
-                        $child_data = @unserialize($raw_data);
-                        //print_r($child_data);
-                        if (!is_array($child_data)) {
-                            // If unserialise fails, it needs to be logged
-                            logger("CHILD #$child_id   ".preg_replace('/^\d\d\:\d\d\:\d\d /','',$raw_data));
-                            return TRUE;
-                        }
-                        if (!array_key_exists('cmd', $child_data))
-                        {
-                            logger('Child #'.$child_id.' sent data with no cmd.');
-                            return TRUE;
-                        }
-                        switch($child_data['cmd'])
-                        {
-                        case 'HEARTBEAT':
-                            break;
-                        case 'START':
-                            if ($child_proc['state'] != 'STARTING')
-                            {
-                                logger('Child #'.$child_id.' sending START after starting.');
-                            } else {
-                                if (array_key_exists('pid', $child_data))
-                                {
-                                    $child_proc['pid'] = $child_data['pid'];
-                                    $child_proc['state'] = 'IDLE';
-                                    logger("START     Child started with PID $child_proc[pid] and idle.\n");
-                                } else {
-                                    logger('START     Child #'.$child_id.' sent START with no PID.');
-                                }
-                            }
-                            break;
-                        case 'ERROR':
-                            if (array_key_exists('msg', $child_data))
-                                logger("Child #$child_id (PID:$child_proc[pid]) got error \"$child_data[msg]\"\n");
-                            else
-                                logger("Child #$child_id (PID:$child_proc[pid]) got error \"unknown error\"\n");
-                            break;
-                        default:
-                            return array($child_id, $child_data);
-                            break;
-                        }// case
+                    if ( ($raw_data = fgets($child_proc['output'])) === FALSE)
+                        continue;
+                    $child_proc['lastseen'] = $now;
+                    $child_data = @unserialize($raw_data);
+                    //print_r($child_data);
+                    if (!is_array($child_data)) {
+                        // If unserialise fails, it needs to be logged
+                        logger("CH$child_id :  RAW:".preg_replace('/^\d\d\:\d\d\:\d\d /','',$raw_data));
+                        $child_had_data = TRUE;
+                        continue;
                     }
-                }
+                    if (!array_key_exists('cmd', $child_data))
+                    {
+                        logger("CH#$child_id: ERROR sent data with no cmd.");
+                        $child_had_data = TRUE;
+                        continue;
+                    }
+                    switch($child_data['cmd'])
+                    {
+                    case 'HEARTBEAT':
+                        $child_had_data = TRUE;
+                        break;
+                    case 'START':
+                        if ($child_proc['state'] != 'STARTING')
+                        {
+                            logger("CH$child_id ($child_proc[pid]): sending START after starting.\n");
+                        } else {
+                            if (array_key_exists('pid', $child_data)) {
+                                $child_proc['pid'] = $child_data['pid'];
+                                $child_proc['state'] = 'IDLE';
+                                logger("CH:$child_id ($child_proc[pid]): START and idle.\n");
+                            } else {
+                                logger("CH:$child_id (unknown): ERROR: child started and did not return PID.\n");
+                            }
+                        }
+                        $child_had_data = TRUE;
+                        break;
+                    case 'DEBUG':
+                        if (array_key_exists('msg', $child_data)) {
+                            logger("CH:$child_id ($child_proc[pid]): DEBUG\n");
+                            foreach ($child_data['msg'] as $line)
+                            logger("  $line\n");
+                        } else
+                            logger("CH:$child_id ($child_proc[pid]): got DEBUG with no message\n");
+                        $child_had_data = TRUE;
+                        break;
+
+                    case 'LOGGER':
+                        if (array_key_exists('msg', $child_data)) {
+                            $msg = stripslashes($child_data['msg']);
+                            logger("CH:$child_id ($child_proc[pid]): $msg\n");
+                        } else
+                            logger("CH:$child_id ($child_proc[pid]): logger called with no msg.\n");
+                        $child_had_data = TRUE;
+                        break;
+                    case 'ERROR':
+                        if (array_key_exists('msg', $child_data))
+                            logger("CH$child_id ($child_proc[pid]): ERROR: \"$child_data[msg]\"\n");
+                        else
+                            logger("CH$child_id ($child_proc[pid]): got error \"unknown error\"\n");
+                        $child_had_data = TRUE;
+                        break;
+                    default:
+                        call_user_func_array($callback_function,array(&$this, $child_id, $child_data));
+                        $child_had_data = TRUE;
+                        break;
+                    }// case
+                }//child output inarry
             }//foreach
-        } // valid select
-        return TRUE;
+        }//nr not false
+        return $child_had_data;
     } // read_children()
 
     /*
@@ -341,7 +379,7 @@ class JffnmsEngineParent
                 $item['tries']++;
                 $item['poll_time'] = time();
                 $this->item_set_polling($item_id);
-                logger("WORK      Child $child_id was idle, working on item $item_id Try $item[tries]\n");
+                logger("PAR: Child $child_id was idle, working on item $item_id Try $item[tries]\n");
                 $this->send_to_child($child_id, 'POLL',$item);
                 break;
             }// foreach child
@@ -355,7 +393,7 @@ class JffnmsEngineParent
     {
         $child_count = array('starting'=>0, 'idle'=>0, 'busy'=>0,'dead'=>0,
             'other'=>0, 'total'=>0 );
-        logger('STATUS    Items Waiting/Polling=Total: '.
+        logger('PAR: Items Waiting/Polling=Total: '.
             $this->waiting_count.'/'.$this->polling_count."\n");
 
         foreach($this->child_procs as $child) {
@@ -368,7 +406,7 @@ class JffnmsEngineParent
             default: $child_count['other']++; break;
             }
         }
-        logger('STATUS    Childn Min/Max Idl/Bsy/Srt/Ded/Otr=Tot: '.
+        logger('PAR: Childn Min/Max Idl/Bsy/Srt/Ded/Otr=Tot: '.
             $this->min_children.'/'.
             $this->max_children.' '.
             "$child_count[idle]/$child_count[busy]/$child_count[starting]/$child_count[dead]/$child_count[other]=$child_count[total]\n");
@@ -391,14 +429,15 @@ class JffnmsEngineParent
     public function child_notdone_job($child_id)
     {
         if (array_key_exists($child_id, $this->child_procs)) {
-            logger("Child #$child_id failed to process item $item_id.\n");
-            $item_id = $this->child_procs[$child_id]['item_id'];
+            $child = $this->child_procs[$child_id];
+            $item_id = $child['item_id'];
+            logger("CH:$child_id (): ** ERROR ** failed to process item $item_id.\n");
             $this->item_set_waiting($item_id);
             $this->child_procs[$child_id]['state'] = 'IDLE';
             $this->child_procs[$child_id]['item_id'] = FALSE;
             return $item_id;
         }
-        logger("** ERROR ** child_notdone_job(): Child ID $child_id not found.\n");
+        logger("CH: $child_id(): ** ERROR ** child_notdone_job(): Child ID $child_id not found.\n");
         return FALSE;
     } // child_notdone_job()
 
@@ -430,7 +469,7 @@ class JffnmsEngineParent
         $msg = serialize($args)."\n";
         $msglen = strlen($msg);
         if ( fwrite($this->child_procs[$child_id]['input'], $msg, $msglen) != $msglen)
-            logger("Error sending message to child #$child_id.\n");
+            logger("CH:$child_id(): ** ERROR ** Parent unable to send message to child.\n");
         fflush($this->child_procs[$child_id]['input']);
     }
 } //class
