@@ -5,11 +5,11 @@
  */
 
 // agGeneral .1.3.6.1.4.1.1872.2.1.2.1
-define(agTftpServer, '.1.3.6.1.4.1.1872.2.1.2.1.18.0');
-define(agTftpCfgFileName, '.1.3.6.1.4.1.1872.2.1.2.1.19.0');
-define(agTftpAction, '.1.3.6.1.4.1.1872.2.1.2.1.21.0');
-define(cfg-get, '3');
-define(agTftpLastActionStatus, '.1.3.6.1.4.1.1872.2.1.2.1.22.0');
+define('agTftpServer', '.1.3.6.1.4.1.1872.2.1.2.1.18.0');
+define('agTftpCfgFileName', '.1.3.6.1.4.1.1872.2.1.2.1.19.0');
+define('agTftpAction', '.1.3.6.1.4.1.1872.2.1.2.1.21.0');
+define('cfg-get', '3');
+define('agTftpLastActionStatus', '.1.3.6.1.4.1.1872.2.1.2.1.22.0');
 
 function config_alteon_webos_get($ip, $community, $server, $filename) {
 
