@@ -70,9 +70,9 @@
     if (sizeof($opts) == 0)
     {
       if (count($_SERVER['argv']) > 1)
-        $times = $_SERVER['argv'][1];
-      if (intval($times) == 0 )
-        print_help("Direct number of repeats must be an integer not \"$times\"\n");
+        $opt_times = $_SERVER['argv'][1];
+      if (intval($opt_times) == 0 )
+        print_help("Direct number of repeats must be an integer not \"$opt_times\"\n");
       return;
     }
     foreach($opts as $opt => $opt_val)
