@@ -1,4 +1,4 @@
-<?
+<?php
 /* TACACS+ Consoliator is part of JFFNMS
  * Copyright (C) <2002> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
