@@ -1,4 +1,4 @@
-<?
+<?php
 /* Cisco Enviorment MIB implementation as part of JFFNMS
  * Copyright (C) <2004> Anders Karlsson <anders.x.karlsson@songnetworks.se>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
