@@ -1,4 +1,4 @@
-<?
+<?php
 /* Cisco SA-AGENT MIB Client Implementation as part of JFFNMS
  * Copyright (C) <2004> Anders Karlsson <anders.x.karlsson@songnetworks.se>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
