@@ -1,4 +1,4 @@
-<?
+<?php
 /* Generic FC Ports . This file is part of JFFNMS
  * Copyright (C) <2006> David LIMA <dlima@fr.scc.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
