@@ -35,7 +35,7 @@
 	    // If it was, get all the other information and return an interface
     	    if ($found==true) {
     		
-		$description 	= snmp_get ($ip, $rocommunity, $sysDescr_oid);
+		$description 	= str_replace("\n",' ',snmp_get ($ip, $rocommunity, $sysDescr_oid));
 		$name 		= snmp_get ($ip, $rocommunity, $sysName_oid);
 		$contact 	= snmp_get ($ip, $rocommunity, $sysContact_oid);
 		$location 	= snmp_get ($ip, $rocommunity, $sysLocation_oid);
