@@ -1,4 +1,4 @@
-<?
+<?php
 /* HostMIB client implementation as part of JFFNMS
  * Copyright (C) <2003> Anders Karlsson <anders.x.karlsson@songnetworks.se>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -25,6 +25,7 @@
 		    	    "process_name"=>$service,
 		    	    "description"=>"Application $path",
 			    "instances"=>1,
+                "ignore_case"=>0,
 		    	    "oper"=>"running"
 			);
 		    else
