@@ -1,4 +1,4 @@
-<?
+<?php
 /* HOST-MIB Sensors implentation as part of JFFNMS.
  * Information from: http://people.redhat.com/harald/snmp-lmsensors/HOWTO-SENSORS-SNMPD.html
  * Copyright (C) <2005> Javier Szyszlican <javier@szysz.com>
