@@ -36,12 +36,12 @@ function discovery_tcp_ports($host,$community, $host_id, $param)
         foreach($nmap_ports as $nmap_port)
         {
           $port_data = explode('/', $nmap_port);
-          if (preg_match('%^(\d+)/open/[a-z]+/([^/]+)/%', $nmap_port, $port_data))
+          if ($port_data[1] == 'open')
           {
-            $port_num = $port_data[1];
+            $port_num = trim($port_data[0]);
             $ports[$port_num] = array(
               'interface' => 'Port '.$port_num,
-              'description' => $port_data[2],
+              'description' => $port_data[4],
               'admin' => 'open',
               'oper' => 'open'
             );
