@@ -1,4 +1,4 @@
-<?
+<?php
 /* Cisco NAT Active Binds Graph. This file is part of JFFNMS.
  * Copyright (C) <2004> Karl S. Hagen <karl_s_hagen@bankone.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
