@@ -1,4 +1,4 @@
-<?
+<?php
 /* Cisco Serial (Async) Port Usage Graph. This file is part of JFFNMS
  * Copyright (C) <2005> Thomas Mangin <thomas.mangin@exa-networks.co.uk>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
