@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002> Robert Bogdon
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
