@@ -1,4 +1,4 @@
-<?
+<?php
 /* IIS Graphs. This file is part of JFFNMS
  * Copyright (C) <2004 Robert St.Denis <service@iahu.ca>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
