@@ -1,4 +1,4 @@
-<?
+<?php
 /* IPTables Chains Aggregation Graph. This file is part of JFFNMS.
  * Copyright (C) <2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
