@@ -1,4 +1,4 @@
-<?
+<?php
 /* Livingston Portmaster Serial Graph. This file is part of JFFNMS
  * Copyright (C) <2004> Javier Szyszlican <javier@szysz.com>
  * Copyright (C) <2004> Thomas Mangin <thomas.mangin@exa-networks.co.uk>
