@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -34,4 +34,4 @@ function graph_tcpmib_connections ($data) {
     return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
-?>
\ No newline at end of file
+?>
