@@ -1,4 +1,4 @@
-<?
+<?php
 /* Aggregate Temperature Graph. This file is part of JFFNMS
  * Copyright (C) <2004> Craig Small <csmall@enc.com.au>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
