@@ -60,11 +60,13 @@ function iad_child_main_loop()
 
 function child_discover_interfaces($params)
 {
+  global $Config, $Child;
   $iad_time = time_msec();
   $Interfaces = new JffnmsInterfaces();
   $InterfaceTypesFields = new JffnmsInterface_types_fields();
+  $Events = new JffnmsEvents();
 
-  $autodiscovery = iad_get_autodiscovery($params['autodiscovery_id']);
+  $ad_policy = iad_get_autodiscovery($params['autodiscovery_id']);
   $interface_types = iad_get_interface_types($params['itype']);
   if ($interface_types === FALSE)
     return FALSE;
@@ -104,33 +106,39 @@ function child_discover_interfaces($params)
         array('itype'=>$itype['id'],'exclude_types'=>20));
     if (is_array($ad_interfaces) && count($ad_interfaces) > 0)
     {
-      $unique_interfaces = array_unique(array_merge(array_merge(array_keys($ad_interfaces), array_keys($db_interfaces))));
+      $unique_interfaces = array_unique(array_merge(array_keys($ad_interfaces), array_keys($db_interfaces)));
+      asort($unique_interfaces);
+      reset($unique_interfaces);
       foreach($unique_interfaces as $key)
       {
         if ($key < 0)
           continue;
         $processed = FALSE;
+	if (isset($db_interfaces[$key]))
+		ksort($db_interfaces[$key]);
+	if (isset($ad_interfaces[$key]))
+		ksort($ad_interfaces[$key]);
+
         discovery_logger($params['host_id'], $itype['id'], $key,
           'DB  : '.(isset($db_interfaces[$key])?iad_show_interface($fields,$db_interfaces[$key]):'Not Found'));
         discovery_logger($params['host_id'], $itype['id'], $key,
           'HOST: '.(isset($ad_interfaces[$key])?iad_show_interface($fields,$ad_interfaces[$key]):'Not Found'));
 
         // Not in DB but in Host = add new
-        if (!isset($db[$key]) && isset($host[$key]))
+        if (!isset($db_interfaces[$key]) && isset($ad_interfaces[$key]))
         {
-          if (iad_permit_new($host[$key], $host_info))
-          {
+          if (iad_permit_new($ad_interfaces[$key], $ad_policy,$itype)) {
             $text = '';
-            discovery_logger($host_info['id'], $it['id'], $key,
+            discovery_logger($params['host_id'], $itype['id'], $key,
               'RES : New Interface Found');
             //if the AD policy permits adding an interface.
-            if ($host_info['permit_add']==1)
+            if ($ad_policy['permit_add']==1)
             {
               //if the AD policy says use default poller
-              if ($host_info['poller_default']==1)
-                ad_set_default ($host[$key]['poll'],$it['autodiscovery_default_poller']); //use the interface type default poller for this new interface
-              ad_set_default ($host[$key]['client'],$host_info['autodiscovery_default_customer']);
-              ad_set_default ($host[$key]['sla'],$it['sla_default']);
+              if ($ad_policy['poller_default']==1)
+                ad_set_default ($ad_interfaces[$key]['poll'],$itype['autodiscovery_default_poller']); //use the interface type default poller for this new interface
+              ad_set_default ($ad_interfaces[$key]['client'],$params['autodiscovery_default_customer']);
+              ad_set_default ($ad_interfaces[$key]['sla'],$itype['sla_default']);
               //Find the Index Field
                foreach ($fields as $fdata)
                 if ($fdata['ftype']==3)
@@ -139,28 +147,105 @@ function child_discover_interfaces($params)
                   break;
                 }
               //add the index field as data to use when adding a record
-              $host[$key][$index_field]=$key;
+              $ad_interfaces[$key][$index_field]=$key;
 
                 //delete the status fields, because they will not be found in the db
-                unset ($host[$key]['admin']);
-                unset ($host[$key]['oper']);
+                unset ($ad_interfaces[$key]['admin']);
+                unset ($ad_interfaces[$key]['oper']);
 
-                $interface_id = adm_interfaces_add(array('host'=>$host_info['id'],'type'=>$it['id'])); //add new record
-                adm_interfaces_update($interface_id,$host[$key]); //update it with the data
+                $interface_id = $Interfaces->add(array('host'=>$params['host_id'],'type'=>$itype['id'])); //add new record
+                $Interfaces->update($interface_id,$ad_interfaces[$key]); //update it with the data
                 $text = '- Added';
               } // permit add
-              if ($log_events==true)
-                insert_event ($now_date, $event_type_id, $host_info['id'], $host[$key]['interface'], //add informative event
+                $Events->add(date("Y-m-d H:i:s",time()), $Config->get('jffnms_administrative_type'), $params['host_id'], $ad_interfaces[$key]['interface'], //add informative event
                   'alert','autodiscovery',trim('Found '.$text),0); 
               $processed = 1;
-            } // if allow add
-          }
+            } // if allow add 
+          continue;
+        } // In Host not DB
 
-      } //foreach unique int id
-    }
-  } //foreach itype
+        if (!isset($ad_interfaces[$key]) && isset($db_interfaces[$key])) {
+            if ($itype['autodiscovery_validate']==1 && $db_interfaces[$key]['poll'] > 1) {
+            discovery_logger($params['host_id'], $itype['id'], $key,
+              'RES : Not Found in Host');
+            $test='';
+            if ($ad_policy['permit_del']==1 && $ad_policy['permit_disable']==0) {
+                $Interfaces->del($db_interfaces[$key]['id']);
+                $text = '- Deleted';
+            }
+            if ($ad_policy['permit_del']==0 && $ad_policy['permit_disable']==1) {
+                $Interfaces->update($db_interfaces[$key]['id'],
+                    array('poll'=>1, 'show_rootmap'=>2));
+                $text = '- Disabled';
+            }
+
+            if ($ad_policy['alert_del']==1)
+                $Events->add(date("Y-m-d H:i:s",time()), $Config->get('jffnms_administrative_type'), $params['host_id'], $db_interfaces[$key]['interface'], //add informative event
+                'alert', 'autodiscovery', trim('Not Found in Host '.$text),0);
+            }
+            continue;
+        }
+
+        // Found in both and polling enabled
+        if (isset($ad_interfaces[$key]) && isset($db_interfaces[$key])) {
+            if ($itype['autodiscovery_validate']==1) {
+                $fields_to_modify = array();
+                $track_fields = array();
+
+                $track_fields['interface']='Interface Name';
+                foreach ($fields as $fdata)
+                    if ($fdata['tracked']==1)
+                        $track_fields[$fdata['name']] = $fdata['description'];
+
+                foreach ($track_fields as $track_field=>$track_field_descr) {
+                    if (!empty($ad_interfaces[$key][$track_field]) &&
+                        (strncmp($ad_interfaces[$key][$track_field], $db_interfaces[$key][$track_field], 30) != 0)) {
+                            discovery_logger($params['host_id'], $itype['id'], $key,
+                                "RES : $track_field_descr changed from ". 
+                                $db_interfaces[$key][$track_field].' to '.
+                                $ad_interfaces[$key][$track_field]);
+                            $fields_to_modify[$track_field]=$ad_interfaces[$key][$track_field];
+                        } // fields not equal
+                    if (count($fields_to_modify) > 0) {
+                        $changed_fields = array();
+                        foreach ($fields_to_modify as $field_name=>$field_value)
+                            $changed_fields[] = $track_fields[$field_name].' to '.$field_value.' was '.$db_interfaces[$key][$field_name];
+                        $changed_fields = join(' and ',$changed_fields);
+
+                        if ($ad_policy['permit_mod']==1) {
+                            $Interfaces->update($db_interfaces[$key]['id'],
+                                $fields_to_modify);
+                            if (array_key_exists('interface', $fields_to_modify))
+                                $interface_name = $ad_interfaces[$key]['interface'];
+                            else
+                                $interface_name = $db_interfaces[$key]['interface'];
+                            $event_comment = '- Changed '.$changed_fields;
+                        } else {
+                            $interface_name = $db_interfaces[$key]['interface'];
+                            $event_comment = '- NOT Changed '.$changed_fields;
+                        }
+                        $Events->add(date("Y-m-d H:i:s",time()), $Config->get('jffnms_administrative_type'), $params['host_id'], $interface_name,
+                'alert', 'autodiscovery', trim('detected modification '.$event_comment),0);
+                    }
+                }
+            }
+
+            // Check for interfaces with no client assigned
+            if ($db_interfaces[$key]['client'] <= 1) {
+                discovery_logger($params['host_id'], $itype['id'], $key,
+                    'RES : No Customer Selected');
+                $Events->add(date("Y-m-d H:i:s",time()), $Config->get('jffnms_administrative_type'), $params['host_id'], $db_interfaces[$key]['interface'],
+                'alert', 'autodiscovery', 'Incomplete interface setup (Customer not selected)', 0);
+                continue;
+            }
+        }
+        discovery_logger($params['host_id'], $itype['id'], $key,
+            'RES : Nothing done.');
+      } // foreach unique interfaces
+    } //ad_interfaces > 0
+  } //interface types
   $iad_time = round(time_msec_diff($iad_time));
-  logger('H '.str_pad($params['host_id'],3,' ',STR_PAD_LEFT)." : Autodiscovery took ".$iad_time." msec.\n");
+  $Child->logger('H '.str_pad($params['host_id'],3,' ',STR_PAD_LEFT)." : Autodiscovery took ".$iad_time." msec.\n");
   return TRUE;
 }
 
@@ -220,7 +305,10 @@ function iad_get_interface_types($itype_id=FALSE)
 
 function discovery_logger($host, $itype, $intid, $result)
 {
-  logger( 'H '.str_pad($host,3,' ',STR_PAD_LEFT).' : '.
+    global $Child;
+
+    $Child->logger(
+          'H '.str_pad($host,3,' ',STR_PAD_LEFT).' : '.
           'IT '.str_pad($itype,3,' ',STR_PAD_LEFT).' : '.
           ($intid?'I '.str_pad($intid,4,' ',STR_PAD_LEFT).' : ':'').
           "$result.\n");
@@ -239,23 +327,30 @@ function iad_show_interface ($fields,$data)
 }
 
 // Not in database but found in host - is it really supposed to be there?
-function iad_permit_new(&$host_data, &$host_info)
+function iad_permit_new(&$host_data, &$ad_policy, &$itype)
 {
-  if ($itype['autodiscovery_validate'] == 1)
-    return FALSE;
+  if ($itype['autodiscovery_validate'] == 0)
+    return TRUE;
 
-  if ($host_info['skip_loopback'] == 1 && (
-    preg_match('/(loopback.*|null.*|lo\d*)$/i', $host_data['interface']) ||
-    (array_key_exists('address', $host_data) && $host_data['address'] == '127.0.0.1')))
-    return FALSE;
+  # If we skip looback and have a loopback address - dont add it
+  if ( // Possibly check for loopback
+	  $ad_policy['skip_loopback'] == 1 &&
+	  (
+	      ( preg_match('/(loopback.*|null.*|lo\d*)$/i', $host_data['interface']) != 0) ||
+	      ( array_key_exists('address', $host_data) && $host_data['address'] == '127.0.0.1')
+      )) {
+	return FALSE; // Skip loopback and loopback detected
+  }
 
-  if ($host_info['check_address'] == 1 && (
-    !array_key_exists('address', $host_data ||
-    $host_data['address'] == '' ||
-    $host_data['address'] == '0.0.0.0')))
-    return FALSE;
+  # Valid address?
+  if ( $ad_policy['check_address'] == 1 &&
+	  (array_key_exists('address', $host_data) == TRUE) &&
+	  ($host_data['address'] == '' || $host_data['address'] == '0.0.0.0')
+  ) 
+	  return FALSE; // Found address and its invalid
 
-  if ($host_info['check_state'] == 1 &&
+  $Alarms = new JffnmsAlarms();
+  if ($ad_policy['check_state'] == 1 &&
     $Alarms->lookup($host_data['oper']) != ALARM_UP)
     return FALSE;
 
@@ -268,6 +363,7 @@ function update_sysobject_id($host_id, $host_ip, $rocommunity)
   $sysObjectId = snmp_get($host_ip, $rocommunity, $oid);
   if ($sysObjectId === FALSE)
     return NULL;
+  $sysObjectId = str_replace('SNMPv2-SMI::enterprises','ent', $sysObjectId);
   db_update('hosts', $host_id, array('sysobjectid' => $sysObjectId));
   return $sysObjectId;
 }
