@@ -69,29 +69,27 @@ function poller_main_loop($opt_once, $opt_host, $opt_children)
 // Read all the children's chatter
 function poller_read_children(&$Parent)
 {
-    $repeats = 10;
+    $read_timeout = max(time() + ENGINE_HEARTBEAT/$Parent->max_children,2);
 
-    while ($repeats--) {
-        $read_retval = $Parent->read_children();
-        if ($read_retval === FALSE)
+    while (time() < $read_timeout) 
+        if ($Parent->read_children('poller_read_callback') == FALSE)
             return;
-        if ($read_retval === TRUE)
-            continue;
-        // otherwise its something we parse
-        list($child_id, $child_data) = $read_retval;
-        switch($child_data['cmd'])
-        {
-        case 'DONE':
-            $item_id = $Parent->child_done_job($child_id);
-            if ($item_id !== FALSE)
-                poller_set_interface_lpd($item_id);
-            break;
-        case 'NOTDONE':
-            $Parent->child_notdone_job($child_id);
-            break;
-        }
-    } // while repeats
-} //poller_read_children()
+}
+
+function poller_read_callback(&$Parent, $child_id, $child_data)
+{
+    switch($child_data['cmd'])
+    {
+    case 'DONE':
+        $item_id = $Parent->child_done_job($child_id);
+        if ($item_id !== FALSE)
+            poller_set_interface_lpd($item_id);
+        break;
+    case 'NOTDONE':
+        $Parent->child_notdone_job($child_id);
+        break;
+    }
+}
 
       
 function parse_commandline()
@@ -234,6 +232,7 @@ function poller_get_interfaces($host_id, $poll_interval)
       'rw_community' => $row['rwcommunity'],
       'ro_community' => $row['rocommunity'],
       'sysobjectid' => $row['sysobjectid'],
+      'check_status' => $row['check_status'],
       'tries' => 0,
       'is_dmii' => FALSE,
       'dmii_up' => 1
