@@ -4,15 +4,15 @@
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
-define(swFCPortPhyState,  '1.3.6.1.4.1.1588.2.1.1.1.6.2.1.3');
-    function poller_brocade_fcport_phystate ($options) {
+function poller_brocade_fcport_phystate ($options) {
+    $swFCPortPhyState = '1.3.6.1.4.1.1588.2.1.1.1.6.2.1.3';
 
 	$community = $options['ro_community'];
 	$ip = $options['host_ip'];
 	$inst = $options['poller_parameters'];
 
 	if ($ip && $community && $inst) {
-		$snmp_value = snmp_get($ip, $community, swFCPortPhyState.".$inst");
+		$snmp_value = snmp_get($ip, $community, $swFCPortPhyState.".$inst");
 		switch ($snmp_value) {
 			case 1:
 				return 'down|No card present';
