@@ -1,4 +1,4 @@
-<?
+<?php
 /* Livingston Portmaster Serial Port Status. This file is part of JFFNMS
  * Copyright (C) <2004> Thomas Mangin <thomas.mangin@exa-networks.co.uk>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
