@@ -10,7 +10,7 @@ function poller_ntp_client ($data)
 
     $ntp_command = $Config->get('ntpq_executable');
     if (!is_executable($ntp_command)) 
-        return 'error';
+        return FALSE;
 
     exec($ntp_command.' -p '.$data['host_ip'].' 2>/dev/null',$raw_result);
     if (count($raw_result)<=2)
