@@ -12,7 +12,7 @@ function poller_reachability_end ($options)
   $uniq = $poller_buffer['ping-'.$options['interface_id']]; //get file id from reachability_start
   $filename = "$temp_path/$uniq.log";
 
-  $result = -1;
+  $result = NULL;
   if (file_exists($filename))
 	  $result = unlink ($filename);
   return $result;
