@@ -8,9 +8,10 @@ function poller_reachability_start ($options)
   global $Config;
 
   $temp_path = $Config->get('engine_temp_path');
+  $uniq=FALSE;
 
   if ( ($host_info = resolve_host($options['host_ip'])) === FALSE)
-    return -1;
+    return FALSE;
   list ($af, $ip, $port) = $host_info;
   if ($af == 6)
     $fping = $Config->get('fping6_executable');
