@@ -9,7 +9,10 @@ function poller_reachability_wait ($options)
   global $poller_buffer;
 
   $temp_path = $Config->get('engine_temp_path');
-  $uniq = $poller_buffer['ping-'.$options['interface_id']]; //get file id from reachability_start
+  $buffer_name ='ping-'.$options['interface_id'];
+  if (!array_key_exists($buffer_name, $poller_buffer))
+      return 'error';
+  $uniq = $poller_buffer[$buffer_name];
 
   $filename = "$temp_path/$uniq.log";
 
