@@ -21,12 +21,13 @@
 
 	list($oid, $valstr) = explode(',', $options['poller_parameters']);
 	$match_pairs = explode('|', $valstr);
+	
 
 	if ($ip && $community && $oid && $valstr) {
 		$snmp_value = snmp_get($ip, $community, $oid);
 		foreach($match_pairs as $match_pair) {
 		    list ($match_string, $return_value) = explode('=', $match_pair);
-		    if (!$match_string || !$return_value) {
+		    if ($match_string==NULL || $return_value==NULL) {
 		        logger("The matching pair \"$match_pair\" is not in <match>=<value> format.\n");
 			return 'down';
 		    }
