@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
@@ -11,7 +11,7 @@ function poller_verify_smokeping_number($options)
     
     $topdir = $options['ro_community'];
     $ifaces = array();
-    scan_dir($topdir, &$ifaces);
+    scan_dir($topdir, $ifaces);
 
     $ifnum = 0;
     foreach($ifaces as $key => $ifname) {
@@ -35,7 +35,7 @@ function poller_verify_smokeping_number($options)
         if ($file == '.' || $file == '..')
 	  continue;
 	if (is_dir($parent.'/'.$file)) {
-	  scan_dir($parent.'/'.$file, &$ifaces);
+	  scan_dir($parent.'/'.$file, $ifaces);
 	} else {
 	  if (preg_match('/\.rrd$/', $file)) {
 	    $ifaces[] = $parent.'/'.$file;
