@@ -61,6 +61,10 @@ function rrd_analizer_main($opt_interface)
       $type_dss[$row['type']] = $interface_data['values'][$row['id']];
       unset ($interface_data);
     }
+    if (!array_key_exists($row['type'], $type_dss)) {
+      logger("I$row[id] : has no values.\n");
+      continue;
+    }
 
     $dss = &$type_dss[$row['type']];
     $values = analyzer_fetch ($row['id'], $start_time, $end_time, $dss);
