@@ -5,7 +5,6 @@
  */
 
 function storage_interface_parse_description ($descr) {
-    $interface = '';
     $description = '';
 
 	$label_hex = strpos($descr,"Hex");
@@ -14,14 +13,21 @@ function storage_interface_parse_description ($descr) {
 		    
 	$descr  = str_replace("\"","",$descr); // UCD-SNMP 4.2.4 fix
 	$descr  = str_replace("\\","",$descr); // Windows Hack for C:\ breaking the DB
+    // By default it is the filtered thing given to us
+	$interface = $descr; 
 
 	//Windows XP Disk Label Hack
 	$label_pos = strpos($descr,"Label");
 	if ($label_pos!==false) {  
 	    $interface = substr($descr,0, $label_pos - 1); //strip the \ and the space
 	    $description = substr($descr,$label_pos, strlen($descr) - $label_pos);
-	} else 
-	    $interface = $descr;
+	} 
+
+    // Juniper JUNOS hack
+    if (preg_match('/mounted on: (\S+)/', $descr, $groups)) {
+        $interface = $groups[1];
+    }
+	
     	    
 	return array($interface, $description);
     }
