@@ -12,6 +12,7 @@ $opt_host=0;
 // main
 { 
   $Hosts = new JffnmsHosts();
+  $HostsConfig = new JffnmsHosts_configs();
 
   $time_total = time_msec();
   parse_commandline();
@@ -41,8 +42,8 @@ $opt_host=0;
     $config_time = time_msec();
     $config_file = $Config->get('jffnms_real_path').'/engine/configs/'.
       $config_row["command"].'.inc.php';
-    $config_get_command = 'hosts_config_'.$config_row['command'].'_get';
-    $config_wait_command = 'hosts_config_'.$config_row['command'].'_wait';
+    $config_get_command = 'config_'.$config_row['command'].'_get';
+    $config_wait_command = 'config_'.$config_row['command'].'_wait';
 
     $now = date("Y-m-d H:i:s",time());
     if (array_key_exists($config_file, $config_included_files))
@@ -58,17 +59,17 @@ $opt_host=0;
         continue;
       }
       require_once($config_file);
-      if (!function_exists($config_get_function))
+      if (!function_exists($config_get_command))
       {
         host_config_logger($config_row, $config_time,
-          "ERROR: Config get function '$config_get_function' does not exist in config file '$config_file'.\n");
+          "ERROR: Config get function '$config_get_command' does not exist in config file '$config_file'.\n");
         $config_included_files[$config_file] = FALSE;
         continue;
       }
-      if (!function_exists($config_wait_function))
+      if (!function_exists($config_wait_command))
       {
         host_config_logger($config_row, $config_time,
-          "ERROR: Config wait function '$config_wait_function' does not exist in config file '$config_file'.\n");
+          "ERROR: Config wait function '$config_wait_command' does not exist in config file '$config_file'.\n");
         $config_included_files[$config_file] = FALSE;
         continue;
       }
@@ -91,19 +92,20 @@ $opt_host=0;
       continue;
     }
       
-    $function_data = array($config['host_ip'],$config['rwcommunity'],$config['tftp_server'],$config_filename);
+    $function_data = array($config_row['host_ip'],$config_row['rwcommunity'],
+        $config_row['tftp_server'],$real_tftp_filename);
     
-    if (call_user_func_array($config_get_function, $function_data) === FALSE)
+    if (call_user_func_array($config_get_command, $function_data) === FALSE)
     {
       host_config_logger($config_row, $config_time,
-        'Getting config file from host');
+        'WARNING: Failed to get config file from host');
       unlink($real_tftp_filename);
       continue;
     }
-    if (call_user_func_array($wait_function, $function_data) === FALSE)
+    if (call_user_func_array($config_wait_command, $function_data) === FALSE)
     {
       host_config_logger($config_row, $config_time,
-        'Waiting for file transfer');
+        'WARNING: Failed waiting for file transfer');
       unlink($real_tftp_filename);
       continue;
     }
@@ -111,13 +113,13 @@ $opt_host=0;
     if (!file_exists($real_tftp_filename) || filesize($real_tftp_filename) == 0)
     {
       host_config_logger($config_row, $config_time,
-        'File did not transfer');
+        'WARNING: file did not transfer');
       unlink($real_tftp_filename);
       continue;
     }
     $config_data_new = file_get_contents($real_tftp_filename);
     unlink($real_tftp_filename);
-    $db_host_configs =  $Hosts->config_list(NULL, $config_row['host_id'],NULL,1);
+    $db_host_configs =  $HostsConfig->get_all(NULL, $config_row['host_id'],NULL,1);
     $config_data_old = $db_host_configs[0]['config'];
     $config_id_old = $db_host_configs[0]['id'];
 
@@ -130,14 +132,14 @@ $opt_host=0;
       $data = array(
         'host'=>$config_row['host_id'],
         'date'=>$now,
-        'config'=>$config_data
+        'config'=>$config_data_new
       );
-      $config_id = $Hosts->config_add();
-      $result = $Hosts->config_update($config_id,$data); //save the config in the DB
+      $config_id = $HostsConfig->add();
+      $result = $HostsConfig->update($config_id,$data); //save the config in the DB
       $info = "new config id $config_id";
     } else  
       $info = "same config as last one ($config_id_old)";
-    hosts_config_logger($config_row, $config_time,'', $info);
+    host_config_logger($config_row, $config_time,'', $info);
   } //while row
   $time_total = time_msec_diff($time_total);
   logger( "TIMES \t: Total Time $time_total msec.\n");
@@ -152,9 +154,9 @@ function host_config_logger(&$config_row, $config_time, $error, $info='')
   if ($error != '')
   {
     $Events = new JffnmsEvents();
-    $Events->add($now, $Config->get('jffnms_administrative_type'),
+    $Events->add(date("Y-m-d H:i:s",time()), $Config->get('jffnms_administrative_type'),
       $config_row['host_id'],'CPU','error','host_config',
-      "Host Config Transfer $error",0,0);
+      'Host Config Transfer: '.addslashes($error),0,0);
   } else
     $error = "OK $info";
 
