@@ -17,6 +17,8 @@ $filter = $Sanitizer->get_string('filter', $host_id);
 $add_to_map_id = $Sanitizer->get_int('add_to_map_id', 1);
 $use_interfaces = $Sanitizer->get_string('use_interfaces');
 $type_id = $Sanitizer->get_int('type_id', FALSE); 
+if (!is_array($use_interfaces))
+    $use_interfaces = explode(',', $use_interfaces);
 
 adm_header('Interfaces');
 
@@ -128,7 +130,7 @@ if (isset($filter))
   $filters['host'] = $filter;
 $interface_count = $Interfaces->get($use_interfaces, $filters);
 
-echo adm_table_header('Interfaces', $init, &$span, $max_fields, $interface_count, 'admin_interfaces', false);
+echo adm_table_header('Interfaces', $init, $span, $max_fields, $interface_count, 'admin_interfaces', false);
 
 if ($interface_count > 0)
 {
