@@ -49,7 +49,7 @@ function nad_ip_protocol($protocol_id)
   return "Unknown ($protocol_id)";
 }
 
-function nad_view_host($host_id, $host, $ips, $ints)
+function nad_view_host($host_id, $host, &$ips, &$ints)
 {
   $host_ips = array();
   $ip_types = array();
@@ -117,7 +117,7 @@ function nad_view_host($host_id, $host, $ips, $ints)
       );
 }
 
-    function nad_view_network ($network, $net, $hosts, $ips) {  
+    function nad_view_network ($network, $net, &$hosts, &$ips) {  
     
   foreach ($net["hosts"] as $host_id) {
       $host = $hosts[$host_id];
@@ -266,7 +266,7 @@ function nad_view_host($host_id, $host, $ips, $ints)
             if (isset($hosts[$nad_id]))
             {
               $host = $hosts[$nad_id];
-              nad_view_host ($nad_id, $host, &$ips, &$ints);
+              nad_view_host ($nad_id, $host, $ips, $ints);
               $shown++;
             }
             break;
@@ -279,7 +279,7 @@ function nad_view_host($host_id, $host, $ips, $ints)
                 if (($only_snmp==0) || !empty($host['snmp_community']))
                 {
                   echo tr_open("", "hosts");
-                  nad_view_host ($host_id, $host, &$ips, &$ints);
+                  nad_view_host ($host_id, $host, $ips, $ints);
                   echo tag_close("tr");
                   $shown++;
                 }
@@ -296,7 +296,7 @@ function nad_view_host($host_id, $host, $ips, $ints)
             }
             if (isset($nets_id[$nad_id]))
             {
-              nad_view_network ($network, $networks[$network], &$hosts, &$ips);
+              nad_view_network ($network, $networks[$network], $hosts, $ips);
               $shown++;
             }
             break;
