@@ -226,7 +226,7 @@ if (($action=='list') && ($adm_view_type=='html'))
 
 //Filter the Records
 if (!empty($filter_field) && ($filter_value!==""))
-  $records = array_record_search(&$records, $filter_field, $filter_value);
+  $records = array_record_search($records, $filter_field, $filter_value);
 
 // SORT Records
 if (!isset($sf) || !isset($so))
@@ -247,7 +247,7 @@ $cant = count($records);
 $show_add = TRUE;
 if (array_key_exists('disable_add', $st) && $st['disable_add'])
   $show_add = FALSE;
-$adm_table_header = adm_table_header($st['title'], $init, &$span, $rows, $cant, 'admin_'.$st_name, $show_add);
+$adm_table_header = adm_table_header($st['title'], $init, $span, $rows, $cant, 'admin_'.$st_name, $show_add);
 
 if ($adm_view_type=='html')
 {
