@@ -22,23 +22,24 @@
   switch ($action)
   {
   case 'update':
-	  #if (is_array($value)) $value = join($value,",");
+      $value = $Sanitizer->get_string('value',array(),TRUE);
+      if (is_array($value))
+          $value = join($value,',');
+      $update_data = array(
+          //'trigger_id' => $Sanitizer->get_int('trigger_id'),
+          'pos' => $Sanitizer->get_int('pos'),
+          'field' => $Sanitizer->get_string('field'),
+          'operator' => $Sanitizer->get_string('operator'),
+          'value' => $value,
+          'action_id' => $Sanitizer->get_int('action_id',1),
+          'stop' => $Sanitizer->get_int('stop',0));
       $action_params = $Sanitizer->get_string('action_params');
       if (is_array($action_params))
       {
           foreach ($action_params as $key=>$data)
               $aux[]="$key:$data";
-	      $action_parameters=join(",",$aux);
+	      $update_data['action_parameters']=join(",",$aux);
 	  }
-      $update_data = array(
-          'trigger_id' => $Sanitizer->get_int('trigger_id'),
-          'pos' => $Sanitizer->get_int('pos'),
-          'field' => $Sanitizer->get_string('field'),
-          'operator' => $Sanitizer->get_string('operator'),
-          'value' => $Sanitizer->get_string('value',array(),TRUE),
-          'action_id' => $actionid,
-          'action_parameters' => $action_parameters,
-          'stop' => $Sanitizer->get_int('stop',0));
 	  $TriggersRules->update($actionid,$update_data);
 	  $action="list";
       break;
