@@ -29,7 +29,7 @@ function users_action_update($api, $actionid)
     $usern = '';
   }
   if ($actionid == 'new' && !empty($usern))
-      $_POST['actionid'] = $api->add($usern);
+      $actionid = $api->add($usern);
 
   $api->modify($actionid, $usern, $old_passwd, $new_passwd, $fullname, $router);
   $GLOBALS['action']='list';
