@@ -447,7 +447,7 @@ function get_structure($struct_name)
       'profile'=>'ADMIN_SYSTEM',
       
       'fields'=>array(
-          'sla'=>array(  'name'=>'SLA',    'type'=>'select',  'func'=>'select_slas',    'size'=>30, 'view'=>'sla_description'),
+          //'sla'=>array(  'name'=>'SLA',    'type'=>'select',  'func'=>'select_slas',    'size'=>30, 'view'=>'sla_description'),
           'pos'=>array(  'name'=>'Position',  'type'=>'textbox', 'size'=>3),
           'cond'=>array(  'name'=>'Condition',  'type'=>'select',  'func'=>'select_slas_cond',  'size'=>30, 'view'=>'cond_description'),
           'show_in_result'=>array(  'name'=>'Show',    'type'=>'checkbox'),
