@@ -23,7 +23,6 @@ adm_header("Interface Selector".(!empty($field_name)?" - ".$field_name:""));
 if ($map_profile = profile('MAP')) $map_id = $map_profile; 
 if ($client_profile = profile('CUSTOMER')) $client_id = $client_profile; 
 
-$select_size = 10;
     
 echo '<script language="JavaScript" src="../scripts/menu_interface_list.js"></script>'.
   script ("
@@ -94,7 +93,7 @@ function print_interface_groups($type, $action, $frame, $map_id, $client_id)
       control_button('Del','_self', 'javascript: del_selected(); ','delete.png'),'buttons','',2).
     tag_close('tr');
     
-    table_row(select_custom ('use_interfaces', array(), '', '', ''),'selector',3);
+    table_row(select_custom ('use_interfaces', array(), '', '', 10),'selector',3);
     table_row(adm_form_submit('View Selected Interfaces'),'view_selected',3);
 
     $show_only_top = FALSE;
