@@ -2,6 +2,8 @@
 function add (name, value)
 {
   select = document.getElementById('use_interfaces');
+  if (!select)
+    select = document.getElementById('use_interfaces[]');
   size = select.length;
   already_added = false;
   
