@@ -14,9 +14,11 @@ $view_all = $Sanitizer->get_int('view_all',0);
 $view_type = $Sanitizer->get_string('view_type', 'html');
 $want_graph = $Sanitizer->get_int('want_graph', 0);
 $graph_times = performance_graph_times();
-$use_interfaces = $Sanitizer->get_int('use_interfaces',NULL);
+$use_interfaces = $Sanitizer->get_string('use_interfaces',NULL);
 if ($use_interfaces==NULL)
   $use_interfaces = $Sanitizer->get_int('interface_id',NULL,TRUE);
+if (!is_array($use_interfaces))
+    $use_interfaces = explode(',', $use_interfaces);
 
 if ($want_graph > 0)
 {
@@ -56,6 +58,8 @@ function performance_graphs_html_header (&$graph_times, $graph_type, $graph_type
   $name = $Sanitizer->get_string('name');
   $hour = (60*60);
   $day = $hour*24;
+  // post/get values to copy for selecting interfaces
+  $interfaces_selectors = array('use_interfaces'); 
 
   $graph_time_presets = array(
     0           => 'No Preset',
@@ -76,28 +80,30 @@ function performance_graphs_html_header (&$graph_times, $graph_type, $graph_type
 
   $colspan=3;
 
-  // ToDo fix QueryString under POST
-  $querystring = $_SERVER["QUERY_STRING"];
-  $clean_url = $Sanitizer->get_url('');
-  $presets_url = $Sanitizer->get_url('', array('name','use_interfaces','graph_type'));
+  $refresh_url = $Sanitizer->get_url('', 'all', FALSE, array('graph_time_start', 'graph_time_stop', 'graph_time_start_hour', 'graph_time_stop_hour'));
+  $presets_url = $Sanitizer->get_url('', array('name','use_interfaces','graph_type','interface_id'));
 
   $shortcuts = array();
 
   if ($client_id > 0)
     $shortcuts[] = linktext(image('logoff.png',0,0,'Logout'),$jffnms_rel_path.'/?logout=1&OldAuth='.$GLOBALS['PHP_AUTH_USER'],'_top');
-  $shortcuts[] = linktext(image('refresh.png',0,16,'Refresh Now'), $clean_url);
+  $shortcuts[] = linktext(image('refresh.png',0,16,'Refresh Now'), $refresh_url);
   $shortcuts[] = tag("img", "", "", "src='images/refresh2.png' alt='' OnClick=\"javascript: if (self.no_refresh!=1) ".
-      "{ self.no_refresh = 1; this.style.display='none'; } else document.location = '".htmlspecialchars($clean_url)."';\"",false);
+      "{ self.no_refresh = 1; this.style.display='none'; } else document.location = '".htmlspecialchars($refresh_url)."';\"",false);
 
   if ($client_id == 0 && profile('ADMIN_HOSTS'))
   {
-    $shortcuts[] = linktext(image('edit.png',0,0,'Edit'), $jffnms_rel_path.'/admin/adm/adm_interfaces.php?'.$querystring);
-    $shortcuts[] = linktext(image('tool.png',0,0,'Tools'),$jffnms_rel_path.'/admin/tools.php?'.$querystring);
+      $shortcuts[] = linktext(image('edit.png',0,0,'Edit'),
+          $Sanitizer->get_url($jffnms_rel_path.'/admin/adm/adm_interfaces.php', $interfaces_selectors));
+      $shortcuts[] = linktext(image('tool.png',0,0,'Tools'),
+          $Sanitizer->get_url($jffnms_rel_path.'/admin/tools.php', $interfaces_selectors));
   }
 
-  $shortcuts[] = linktext(image('text.png',0,0,'Report'),$jffnms_rel_path.'/admin/reports/state_report.php?'.$querystring);
+  $shortcuts[] = linktext(image('text.png',0,0,'Report'),
+      $Sanitizer->get_url($jffnms_rel_path.'/admin/reports/state_report.php', $interfaces_selectors));
 
-  $shortcuts[] = linktext(image('csv.png',0,0,'Export as CSV'),$clean_url.'&view_type=csv');
+  $shortcuts[] = linktext(image('csv.png',0,0,'Export as CSV'),
+      $Sanitizer->get_url('', 'all', array('view_type'=>'csv')));
 
   $shortcuts[] = linktext(image('a-top.png',0,0,'Hide','','hide'),
     "javascript: hide_menu('options_header', 'options', 'hide','images/a-top.png', 'images/a1-down.png');");
