@@ -25,16 +25,19 @@ function logger($text, $show_date = true)
 
   if ($Config->get('jffnms_debug')==1)
   {
-    $file = str_replace('.php','',basename($Config->get('logging_file')));
-    $filename = $Config->get('log_path').'/'.$file.'-'.date('Y-m-d').'.log';
+      if (array_key_exists('Child', $GLOBALS)) {
+          $GLOBALS['Child']->logger($text);
+          return;
+      }  
+      $file = str_replace('.php','',basename($Config->get('logging_file')));
+      $filename = $Config->get('log_path').'/'.$file.'-'.date('Y-m-d').'.log';
 
-    if ( ($log = fopen($filename,"a+")) === FALSE)
-    {
-      print "Unable to open log file $filename.\n";
-      return;
-    }
-    fputs($log, $text);
-    fclose($log);
+      if ( ($log = fopen($filename,'a+')) === FALSE) {
+          print "Unable to open log file $filename.\n";
+          return;
+      }
+      fputs($log, $text);
+      fclose($log);
   }
   echo $text;
 }
@@ -73,6 +76,18 @@ function vd($data,$pos = 1)
   return $result;
 }
 
+// Youre kidding me right? the float and floatvar are not locale
+// aware? Really?
+// Lucky for us rrdtool exports things as scientific notation so we don't
+// need to worry about thousand separators
+function str2f($str)
+{
+    $linfo = localeconv();
+    $str = str_replace(',','.',$str);
+    return floatval($str);
+}
+
+
 // TIME FUNCTIONS
 //-----------------------------------------
 //
