@@ -70,13 +70,16 @@ function snmp_walk ($host, $comm, $oid, $include_oid = INCLUDE_OID_NONE, $retrie
 
   if ($include_oid > INCLUDE_OID_BASE)
     $result = snmp_reduce_table_key ($result, $include_oid-INCLUDE_OID_BASE);
-  foreach  ($result as $oid => $value)
+  $new_result = array();
+  foreach  ($result as $oid => $value) {
       if (
           (strpos($value, 'No Such Instance') !== FALSE) or
           (strpos($value, 'No Such Object') !== FALSE) or
           (strpos($value, 'No more variables left') !== FALSE) )
-          unset($result[$oid]);
-  return $result;
+          continue;
+      $new_result[$oid] = snmp_fix_value($value);
+  }
+  return $new_result;
 }
 
 function snmp_get ($host, $comm, $oid, $retries = 2)
@@ -107,7 +110,7 @@ function snmp_get ($host, $comm, $oid, $retries = 2)
       (strpos($result, 'No Such Object') !== FALSE) or
       (strpos($result, 'No more variables left') !== FALSE) )
     return FALSE;
-  return $result;
+  return snmp_fix_value($result);
 }
     
 function snmp_set ($host, $comm, $oid, $type, $value, $retries = 2)
@@ -158,17 +161,17 @@ function parse_oid ($oid, $version = 1)
 
 function snmp_fix_value ($value)
 {
-  $value = trim ($value);
-  if (strpos($value,'=') !== false)           // if it has = in the value
-    $value = substr($value, strpos($value,'=')+2, strlen($value));  // return only the data after the =
+    if ($value === FALSE)
+        return FALSE;
+    $value = preg_replace('/(counter32|counter64|gauge|gauge32|gauge64|hex|ipaddress|integer|string):/i', '', $value);
+    if ($value == '')
+        return '';
+    if (is_numeric($value))
+        return trim($value);
 
-  if ($value=preg_replace('/INTEGER: /','',$value))
-    return $value;
-  
-  if (preg_match("/^\"(\S.+)\"$/",$value,$parts)) $value = $parts[1];
-  if (preg_match("/STRING: \"(\S.+)\"/",$value,$parts)) $value = $parts[1];
-
-  return preg_replace('/(?:STRING|IpAddress|Gauge32|Counter32|Counter64): /','',$value);
+    // Remove quotes and other delimiters
+    $value = str_replace(array("\"","'",">","<","\\","\n","\r"),'', $value);
+    return trim($value);
 }
     
 function snmp_reduce_table_key ($table, $important = 1)
