@@ -50,11 +50,12 @@ function rrdtool($method,$file,$opts,$force_no_module = 0)
     $command .= ' --daemon '.RRDCACHED_SOCKET;
 
   //debug($command);
+  $command .= ' 2>&1';
         
   if ($use_pipe)
     list ($ret1, $ret2) = rrd_pipe($method." '".$file."' ".$aux);
   else
-    exec($command,$ret1,$ret2);
+    $ret3 = exec($command,$ret1,$ret2);
     
   //debug($ret1);
   //debug($ret2);
@@ -74,7 +75,7 @@ function rrdtool($method,$file,$opts,$force_no_module = 0)
           {
             for ($i = 1; $i < count($line1); $i++)      // Part 1 is timestamp
               if ($line1[$i]!=="")           // Part 2 maybe is a space
-                $value[] = ($line1[$i]=="nan")?0:(float)$line1[$i]; // Part 3 (or 2) has the data
+                $value[] = ($line1[$i]=="nan")?0:str2f($line1[$i]); // Part 3 (or 2) has the data
             $date = (int)$line1[0];          // Time Stamp
             if (!isset($stop)) $stop=0;
             if ($date > $stop) $stop = $date;
@@ -111,6 +112,7 @@ function rrdtool($method,$file,$opts,$force_no_module = 0)
       if ($ret2 != 0 )
       {
         $error=1; $ret = 0;
+        $info .+ $ret3;
       }
       break;
     case 'last':
@@ -125,8 +127,12 @@ function rrdtool($method,$file,$opts,$force_no_module = 0)
     $error=1; $ret = 0;
   }
   
-  if ($error==1)
-    echo("rrd_$method() ERROR: $info");
+  if ($error==1) {
+      if (array_key_exists('Child', $GLOBALS)) {
+          $GLOBALS['Child']->send_error("rrd_$method(): $ret3");
+      } else
+          echo("rrd_$method() ERROR: $info");
+  }
   return $ret;
 }
 
