@@ -198,7 +198,7 @@ function select_filters_fields ($name,$id, $add_data = NULL, $onchange = "", $pa
 
 function select_slas_cond ($name,$id, $add_data = NULL, $onchange = "", $params = array())
 {
-  $SLAs_cond = new JffnmsSlas_conds();
+  $SLAs_cond = new JffnmsSlas_cond();
   return select_object($SLAs_cond,$name,$id,$add_data,'id','description',$params,1,$onchange);
 } 
 
@@ -295,9 +295,9 @@ function select_pollers_groups ($name,$poller_group_id,$type = 0)
 
   if ($text==0)
       return select_custom($name,$trigger_op,$value);
-  else 
+  if (array_key_exists($value, $trigger_op))
       return $trigger_op[$value];
-      
+  return '';
     }
 
     function get_trigger_fields($type)
@@ -357,10 +357,8 @@ function select_trigger_fields_value($name,$value,$type,$field)
 {
   $trigger_fields = get_trigger_fields($type);
     
-  //var_dump(array($type, $field));
-  #if ((!$field) || ($field=='any') || ($field=='none')) 
-  if ( ($field=='any') || ($field=='none')) 
-    return "field $field f";
+  if ((!$field) || ($field=='any') || ($field=='none')) 
+      return '';
   else 
     return call_user_func_array($trigger_fields[$field]['function'],
     array_merge(array($name, $value), $trigger_fields[$field]['params']));
