@@ -429,7 +429,7 @@ function profile ($tag, $set_value = NULL)
   $ProfilesValues = new JffnmsProfiles_values();
   
   if ($set_value != NULL)
-    $Profiles->update($_SESSION['auth_user_id'], $tag, $set_value);
+    $ProfilesValues->modify($_SESSION['auth_user_id'], $tag, $set_value);
   $value = $ProfilesValues->get_value($tag,$_SESSION['auth_user_id']);
   return $value;
 }
