@@ -193,6 +193,8 @@ function image($src, $w = '', $h = '', $title = '', $class='', $id = '', $onclic
     }
 
     function linktext ($text, $url, $target="" ,$class = "", $on_click = "", $id = "", $style = "") {
+        if (is_array($target))
+            $target = $target[0];
   return
       html ("a", $text, $id, $class, 
     (!empty($target)?" target='".$target."'":"").
@@ -208,6 +210,8 @@ function image($src, $w = '', $h = '', $title = '', $class='', $id = '', $onclic
     }
 
     function hidden($name,$value) { 
+        if (is_array($value))
+            $value = $value[0];
   return tag ("input","","","type='hidden' name='".$name."' value='".$value."'", false);
     }
 
